% S Adhikari: June 2006, Bristol
% Hom_EXP is Nsamp x Nfreq  x Nchan array of measured transfer functions
% Nsamp: number of samples, 100
% Nfreq: number of frequency points
% Nchan: number of output channels = 3 
% Hom_EXP_baseline is the FRF of the baseline model (ie, no attached masses)
% f_max is maximum frequency (8192 Hz)- [need to change it later]
% omega is the array of the driving frequency in rad/s,  
%                           omega=(0:1:f_max).*(2*pi);.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all; clear all;
load BeamEXPdata;  load MassLocations;

fsize=14;fname='times';
y_min=-30;y_max=70;


f_max=4.5e3; % Maximum freq in Hz (change f_max to fit in the plots)
f_low=0.8e3; % Low freq vibration limit (border between low and mid)
f_mid=2.2e3; % Low freq vibration limit (border between mid and high)

% Only consider freq below 4.5KHz
[jk,id_EXP,omega_EXP]=find( omega < f_max*2*pi);
omega_EXP=omega(id_EXP);
n_EXP=length(omega_EXP);

% Calculate statistics
for jplot=1:3   
    stat_ABS_EXP(1,:,jplot)=20*log10(mean(abs(Hom_EXP(:,1:n_EXP,jplot))));
    stat_ABS_EXP(2,:,jplot)=20*log10(prctile(abs(Hom_EXP(:,1:n_EXP,jplot)),5));
    stat_ABS_EXP(3,:,jplot)=20*log10(prctile(abs(Hom_EXP(:,1:n_EXP,jplot)),95));
    stat_ABS_EXP(4,:,jplot)=20*log10(std(abs(Hom_EXP(:,1:n_EXP,jplot))));
    stat_ABS_EXP(5,:,jplot)=(std(abs(Hom_EXP(:,1:n_EXP,jplot))))./(mean(abs(Hom_EXP(:,1:n_EXP,jplot))));

% Phase
    stat_PHS_EXP(1,:,jplot)=(mean(angle(-Hom_EXP(:,1:n_EXP,jplot))));
    stat_PHS_EXP(2,:,jplot)=(prctile(angle(-Hom_EXP(:,1:n_EXP,jplot)),5));
    stat_PHS_EXP(3,:,jplot)=(prctile(angle(-Hom_EXP(:,1:n_EXP,jplot)),95));
    stat_PHS_EXP(4,:,jplot)=(std(angle(-Hom_EXP(:,1:n_EXP,jplot))));
        
end

% Plot & save all experimental samples: absolute value
for jplot=1:3    
   figure(jplot);clf;hold all;
   		plot(...
   		      omega_EXP/2/pi,20*log10(abs(Hom_EXP_baseline(jplot,1:n_EXP))),'-.m',...
   		      omega_EXP/2/pi,stat_ABS_EXP(1,:,jplot),'-r', ...
   		      omega_EXP/2/pi,stat_ABS_EXP(2,:,jplot),'--b',...
   		      omega_EXP/2/pi,stat_ABS_EXP(3,:,jplot),':k','linewidth',1.5);      
   		h2=legend('Baseline','Ensamble mean ','5% points','95% points');
   		plot(omega_EXP/2/pi,20*log10(abs(Hom_EXP(:,1:n_EXP,jplot))),'-',...
   		     'Color',[0.75 0.75 0.77],'linewidth',0.5);
   		plot(...
   		      omega_EXP/2/pi,20*log10(abs(Hom_EXP_baseline(jplot,1:n_EXP))),'-.m',...
   		      omega_EXP/2/pi,stat_ABS_EXP(1,:,jplot),'-r', ...
   		      omega_EXP/2/pi,stat_ABS_EXP(2,:,jplot),'--b',...
   		      omega_EXP/2/pi,stat_ABS_EXP(3,:,jplot),':k','linewidth',1.5);      
   		xlabel('Frequency (Hz)','FontName',fname,'fontsize',fsize)
   		ylabel(['Log amplitude (dB) of H_{(2,' int2str(jplot) ')} (\omega)'],'FontName',fname,'fontsize',fsize)
   		ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
	 	set(h2,'Location','Best','linewidth',0.5,'FontName',fname,'FontSize',10);
        t1=axis;t2=t1;t2(2)=f_max;t2(3)=y_min;t2(4)=y_max;axis(t2);
        eval(['print -depsc BeamEXP_ABS_FRF' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 BeamEXP_ABS_FRF' num2str(jplot) '.jpeg' ]);
        hgsave(['BeamEXP_ABS_FRF' num2str(jplot) '.fig' ]);
       
        % Save Low frequency vibration
        t2(2)=f_low;t2(3)=y_min;t2(4)=y_max;axis(t2); 
        eval(['print -depsc BeamEXP_ABS_FRF_LowFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 BeamEXP_ABS_FRF_LowFreq' num2str(jplot) '.jpeg' ]);
          
        % Save Mid frequency vibration
        t2(1)=f_low;t2(2)=f_mid;t2(3)=y_min;t2(4)=y_max;axis(t2); 
        eval(['print -depsc BeamEXP_ABS_FRF_MidFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 BeamEXP_ABS_FRF_MidFreq' num2str(jplot) '.jpeg' ]);
          
        % Save High frequency vibration
        t2(1)=f_mid;t2(2)=f_max;t2(3)=y_min;t2(4)=y_max;axis(t2); 
        eval(['print -depsc BeamEXP_ABS_FRF_HiFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg90 BeamEXP_ABS_FRF_HiFreq' num2str(jplot) '.jpeg' ]);
          
        % Get back to the actual plot
        t2(1)=t1(1);t2(2)=f_max;t2(3)=y_min;t2(4)=y_max;axis(t2);                 
end


% Plott & save all experimental samples: phase angle
for jplot=1:3    
      figure(jplot+3);clf;hold all;
        plot(...
              omega_EXP/2/pi,(angle(-Hom_EXP_baseline(jplot,1:n_EXP))),'-.r',...
              omega_EXP/2/pi,stat_PHS_EXP(1,:,jplot),'-m', ...
              omega_EXP/2/pi,stat_PHS_EXP(2,:,jplot),'--b',...
              omega_EXP/2/pi,stat_PHS_EXP(3,:,jplot),':k','linewidth',1.5);      
        h2=legend('Baseline','Ensemble mean ','5% points','95% points');
        plot(omega_EXP/2/pi,(angle(-Hom_EXP(:,1:n_EXP,jplot))),'-',...
             'Color',[0.75 0.75 0.77],'linewidth',0.5);
        plot(...
              omega_EXP/2/pi,(angle(-Hom_EXP_baseline(jplot,1:n_EXP))),'-.r',...
              omega_EXP/2/pi,stat_PHS_EXP(1,:,jplot),'-m', ...
              omega_EXP/2/pi,stat_PHS_EXP(2,:,jplot),'--b',...
              omega_EXP/2/pi,stat_PHS_EXP(3,:,jplot),':k','linewidth',1.5);      
   		xlabel('Frequency (Hz)','FontName',fname,'fontsize',fsize)
   		ylabel(['Phase of H_{(2,' int2str(jplot) ')} (\omega)'],'FontName',fname,'fontsize',fsize)
        ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
        t1=axis;t2=t1;t2(2)=f_max;t2(3)=-4.0;t2(4)=4.0;axis(t2);
        set(h2,'Location','Best','linewidth',0.5,'FontName',fname,'FontSize',10);
        eval(['print -depsc BeamEXP_PHS_FRF' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 BeamEXP_PHS_FRF' num2str(jplot) '.jpeg' ]);
        hgsave(['BeamEXP_PHS_FRF' num2str(jplot) '.fig' ]);

        % Save Low frequency vibration
        t2(2)=f_low;axis(t2); 
        eval(['print -depsc BeamEXP_PHS_FRF_LowFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 BeamEXP_PHS_FRF_LowFreq' num2str(jplot) '.jpeg' ]);
          
        % Save Mid frequency vibration
        t2(1)=f_low;t2(2)=f_mid;axis(t2); 
        eval(['print -depsc BeamEXP_PHS_FRF_MidFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 BeamEXP_PHS_FRF_MidFreq' num2str(jplot) '.jpeg' ]);
          
        % Save High frequency vibration
        t2(1)=f_mid;t2(2)=f_max;axis(t2); 
        eval(['print -depsc BeamEXP_PHS_FRF_HiFreq' num2str(jplot) '.eps' ]);
        eval(['print -djpeg100 BeamEXP_PHS_FRF_HiFreq' num2str(jplot) '.jpeg' ]);
          
        % Get back to the actual plot
        t2(1)=t1(1);t2(2)=f_max;axis(t2);         
end


% Plot the mass locations for different samples
nsamp=100;nvar=12;nsamp_plot=100;
figure(7)
for j=1:nsamp
    xma(:,j)=sort(MassLocations(:,j));
end
plot(xma(:,1:nsamp_plot),[1:nsamp_plot],'o-', 'MarkerEdgeColor','k',...
                'MarkerFaceColor','r',...
                'MarkerSize',7);
xlabel('Length along the beam (m)','FontName',fname,'fontsize',fsize);
ylabel('Sample number','FontName',fname,'fontsize',fsize);
axis([0,1.2,1,nsamp_plot]);grid on;
ha=gca;set(ha,'linewidth',1.5,'FontName',fname,'FontSize',fsize,'Box','on');
print -depsc BeamMassPositions.eps
print -djpeg100 BeamMassPositions.jpeg
mean(xma')    
std(xma')


